@@ -10,7 +10,7 @@
 #include "bg.h"
 #include "sprite.h"
 #include "interrupt.h"
-
+#include "sound.h"
 #include "fixed.h"
 
 extern const unsigned char intro_planet_Bitmap[7680];
@@ -19,6 +19,8 @@ extern const unsigned char font_Bitmap[4096];
 extern const unsigned short sprites_Palette[256];
 extern const unsigned char sprites_Bitmap[16384];
 
+extern SAMPLE laser_sample;
+extern SAMPLE exp_sample;
 
 /* explosion animation info */
 #define EXPLOSION_FRAMES_NUM 5
